@@ -273,19 +273,24 @@ def test_client_poll(server):
     ids = {
         query.SECTORS: 42,
         query.INPUTS: 4242,
+        query.OUTPUTS: 424,
+        query.ALERTS: 424242,
     }
     # Test
     state = client.poll(ids)
-    assert len(state.keys()) == 3
+    assert len(state.keys()) == 5
     # Check response
     assert state["has_changes"] is False
     assert state["inputs"] is False
     assert state["areas"] is False
+    assert state["outputs"] is False
+    assert state["statusadv"] is False
     # Check request
     body = server.calls[0].request.body.split("&")
     assert "sessionId=test" in body
     assert "Areas=42" in body
     assert "Inputs=4242" in body
+    assert "Outputs=424" in body
     assert "CanElevate=1" in body
     assert "ConnectionStatus=1" in body
 
@@ -301,14 +306,14 @@ def test_client_poll_with_changes(server):
             "Areas": true,
             "Events": false,
             "Inputs": true,
-            "Outputs": false,
+            "Outputs": true,
             "Anomalies": false,
             "ReadStringsInProgress": false,
             "ReadStringPercentage": 0,
             "Strings": 0,
             "ManagedAccounts": false,
             "Temperature": false,
-            "StatusAdv": false,
+            "StatusAdv": true,
             "Images": false,
             "AdditionalInfoSupported": true,
             "HasChanges": true
@@ -320,13 +325,17 @@ def test_client_poll_with_changes(server):
     ids = {
         query.SECTORS: 42,
         query.INPUTS: 4242,
+        query.OUTPUTS: 424,
+        query.ALERTS: 424242,
     }
     # Test
     state = client.poll(ids)
-    assert len(state.keys()) == 3
+    assert len(state.keys()) == 5
     assert state["has_changes"] is True
     assert state["inputs"] is True
     assert state["areas"] is True
+    assert state["outputs"] is True
+    assert state["statusadv"] is True
 
 
 def test_client_poll_ignore_has_changes(server):
@@ -359,10 +368,12 @@ def test_client_poll_ignore_has_changes(server):
     ids = {
         query.SECTORS: 42,
         query.INPUTS: 4242,
+        query.OUTPUTS: 424,
+        query.ALERTS: 424242,
     }
     # Test
     state = client.poll(ids)
-    assert len(state.keys()) == 3
+    assert len(state.keys()) == 5
     assert state["has_changes"] is False
 
 
@@ -379,6 +390,8 @@ def test_client_poll_unknown_error(server):
     ids = {
         query.SECTORS: 42,
         query.INPUTS: 4242,
+        query.OUTPUTS: 424,
+        query.ALERTS: 424242,
     }
     # Test
     with pytest.raises(HTTPError):
@@ -386,39 +399,154 @@ def test_client_poll_unknown_error(server):
     assert len(server.calls) == 1
 
 
-def test_client_poll_parse_error(server):
-    """Should raise a ParseError if the response is different from what is expected.
-    In this case `Areas` and `Inputs` are missing from the response."""
-    html = """
-        {
-            "ConnectionStatus": false,
-            "CanElevate": false,
-            "LoggedIn": false,
-            "LoginInProgress": false,
-            "Events": false,
-            "Outputs": false,
-            "Anomalies": false,
-            "ReadStringsInProgress": false,
-            "ReadStringPercentage": 0,
-            "Strings": 0,
-            "ManagedAccounts": false,
-            "Temperature": false,
-            "StatusAdv": false,
-            "Images": false,
-            "AdditionalInfoSupported": true,
-            "HasChanges": false
+class TestClientPollParseError:
+    def test_areas_missing(self, server):
+        """Should raise a ParseError if the response is different from what is expected.
+        In this case `Areas` is missing from the response."""
+        html = """
+            {
+                "ConnectionStatus": false,
+                "CanElevate": false,
+                "LoggedIn": false,
+                "LoginInProgress": false,
+                "Events": true,
+                "Inputs": false,
+                "Outputs": false,
+                "Anomalies": false,
+                "ReadStringsInProgress": false,
+                "ReadStringPercentage": 0,
+                "Strings": 0,
+                "ManagedAccounts": false,
+                "Temperature": false,
+                "StatusAdv": false,
+                "Images": false,
+                "AdditionalInfoSupported": true,
+                "HasChanges": false
+            }
+        """
+        server.add(responses.POST, "https://example.com/api/updates", body=html, status=200)
+        client = ElmoClient(base_url="https://example.com", domain="domain")
+        client._session_id = "test"
+        ids = {
+            query.SECTORS: 42,
+            query.INPUTS: 4242,
+            query.OUTPUTS: 424,
+            query.ALERTS: 424242,
         }
-    """
-    server.add(responses.POST, "https://example.com/api/updates", body=html, status=200)
-    client = ElmoClient(base_url="https://example.com", domain="domain")
-    client._session_id = "test"
-    ids = {
-        query.SECTORS: 42,
-        query.INPUTS: 4242,
-    }
-    # Test
-    with pytest.raises(ParseError):
-        client.poll(ids)
+        # Test
+        with pytest.raises(ParseError):
+            client.poll(ids)
+
+    def test_inputs_missing(self, server):
+        """Should raise a ParseError if the response is different from what is expected.
+        In this case `Inputs` is missing from the response."""
+        html = """
+            {
+                "ConnectionStatus": false,
+                "CanElevate": false,
+                "LoggedIn": false,
+                "LoginInProgress": false,
+                "Areas": false,
+                "Events": true,
+                "Outputs": false,
+                "Anomalies": false,
+                "ReadStringsInProgress": false,
+                "ReadStringPercentage": 0,
+                "Strings": 0,
+                "ManagedAccounts": false,
+                "Temperature": false,
+                "StatusAdv": false,
+                "Images": false,
+                "AdditionalInfoSupported": true,
+                "HasChanges": false
+            }
+        """
+        server.add(responses.POST, "https://example.com/api/updates", body=html, status=200)
+        client = ElmoClient(base_url="https://example.com", domain="domain")
+        client._session_id = "test"
+        ids = {
+            query.SECTORS: 42,
+            query.INPUTS: 4242,
+            query.OUTPUTS: 424,
+            query.ALERTS: 424242,
+        }
+        # Test
+        with pytest.raises(ParseError):
+            client.poll(ids)
+
+    def test_outputs_missing(self, server):
+        """Should raise a ParseError if the response is different from what is expected.
+        In this case `Outputs` is missing from the response."""
+        html = """
+            {
+                "ConnectionStatus": false,
+                "CanElevate": false,
+                "LoggedIn": false,
+                "LoginInProgress": false,
+                "Areas": false,
+                "Events": true,
+                "Inputs": false,
+                "Anomalies": false,
+                "ReadStringsInProgress": false,
+                "ReadStringPercentage": 0,
+                "Strings": 0,
+                "ManagedAccounts": false,
+                "Temperature": false,
+                "StatusAdv": false,
+                "Images": false,
+                "AdditionalInfoSupported": true,
+                "HasChanges": false
+            }
+        """
+        server.add(responses.POST, "https://example.com/api/updates", body=html, status=200)
+        client = ElmoClient(base_url="https://example.com", domain="domain")
+        client._session_id = "test"
+        ids = {
+            query.SECTORS: 42,
+            query.INPUTS: 4242,
+            query.OUTPUTS: 424,
+            query.ALERTS: 424242,
+        }
+        # Test
+        with pytest.raises(ParseError):
+            client.poll(ids)
+
+    def test_statusadv_missing(self, server):
+        """Should raise a ParseError if the response is different from what is expected.
+        In this case `StatusAdv` is missing from the response."""
+        html = """
+            {
+                "ConnectionStatus": false,
+                "CanElevate": false,
+                "LoggedIn": false,
+                "LoginInProgress": false,
+                "Areas": false,
+                "Events": true,
+                "Inputs": false,
+                "Outputs": false,
+                "Anomalies": false,
+                "ReadStringsInProgress": false,
+                "ReadStringPercentage": 0,
+                "Strings": 0,
+                "ManagedAccounts": false,
+                "Temperature": false,
+                "Images": false,
+                "AdditionalInfoSupported": true,
+                "HasChanges": false
+            }
+        """
+        server.add(responses.POST, "https://example.com/api/updates", body=html, status=200)
+        client = ElmoClient(base_url="https://example.com", domain="domain")
+        client._session_id = "test"
+        ids = {
+            query.SECTORS: 42,
+            query.INPUTS: 4242,
+            query.OUTPUTS: 424,
+            query.ALERTS: 424242,
+        }
+        # Test
+        with pytest.raises(ParseError):
+            client.poll(ids)
 
 
 def test_client_lock(server, mocker):
@@ -645,7 +773,35 @@ def test_client_arm(server):
     assert "sessionId=test" in body
 
 
-def test_client_arm_sectors(server):
+def test_client_arm_single_sector(server):
+    """Should call the API and arm only the given sector."""
+    html = """[
+        {
+            "Poller": {"Poller": 1, "Panel": 1},
+            "CommandId": 5,
+            "Successful": true
+        }
+    ]"""
+    server.add(
+        responses.POST,
+        "https://example.com/api/panel/syncSendCommand",
+        body=html,
+        status=200,
+    )
+    client = ElmoClient(base_url="https://example.com", domain="domain")
+    client._session_id = "test"
+    client._lock.acquire()
+    # Test
+    assert client.arm([3]) is True
+    assert len(server.calls) == 1
+    body = server.calls[0].request.body.split("&")
+    assert "CommandType=1" in body
+    assert "ElementsClass=9" in body
+    assert "ElementsIndexes=3" in body
+    assert "sessionId=test" in body
+
+
+def test_client_arm_multiple_sectors(server):
     """Should call the API and arm only the given sectors."""
     html = """[
         {
@@ -665,15 +821,11 @@ def test_client_arm_sectors(server):
     client._lock.acquire()
     # Test
     assert client.arm([3, 4]) is True
-    assert len(server.calls) == 2
+    assert len(server.calls) == 1
     body = server.calls[0].request.body.split("&")
     assert "CommandType=1" in body
     assert "ElementsClass=9" in body
     assert "ElementsIndexes=3" in body
-    assert "sessionId=test" in body
-    body = server.calls[1].request.body.split("&")
-    assert "CommandType=1" in body
-    assert "ElementsClass=9" in body
     assert "ElementsIndexes=4" in body
     assert "sessionId=test" in body
 
@@ -773,7 +925,35 @@ def test_client_disarm(server):
     assert "sessionId=test" in body
 
 
-def test_client_disarm_sectors(server):
+def test_client_disarm_single_sector(server):
+    """Should call the API and disarm only the given sector."""
+    html = """[
+        {
+            "Poller": {"Poller": 1, "Panel": 1},
+            "CommandId": 5,
+            "Successful": true
+        }
+    ]"""
+    server.add(
+        responses.POST,
+        "https://example.com/api/panel/syncSendCommand",
+        body=html,
+        status=200,
+    )
+    client = ElmoClient(base_url="https://example.com", domain="domain")
+    client._session_id = "test"
+    client._lock.acquire()
+    # Test
+    assert client.disarm([3]) is True
+    assert len(server.calls) == 1
+    body = server.calls[0].request.body.split("&")
+    assert "CommandType=2" in body
+    assert "ElementsClass=9" in body
+    assert "ElementsIndexes=3" in body
+    assert "sessionId=test" in body
+
+
+def test_client_disarm_multiple_sectors(server):
     """Should call the API and disarm only the given sectors."""
     html = """[
         {
@@ -793,15 +973,11 @@ def test_client_disarm_sectors(server):
     client._lock.acquire()
     # Test
     assert client.disarm([3, 4]) is True
-    assert len(server.calls) == 2
+    assert len(server.calls) == 1
     body = server.calls[0].request.body.split("&")
     assert "CommandType=2" in body
     assert "ElementsClass=9" in body
     assert "ElementsIndexes=3" in body
-    assert "sessionId=test" in body
-    body = server.calls[1].request.body.split("&")
-    assert "CommandType=2" in body
-    assert "ElementsClass=9" in body
     assert "ElementsIndexes=4" in body
     assert "sessionId=test" in body
 
@@ -1135,6 +1311,224 @@ def test_client_exclude_fails_unknown_error(server):
     assert len(server.calls) == 1
 
 
+class TestTurnOn:
+    def test_client_single_output(self, server):
+        """Should call the API and activate given output."""
+        html = """[
+            {
+                "Poller": {"Poller": 1, "Panel": 1},
+                "CommandId": 147,
+                "Successful": true,
+                "ErrorMessages": []
+            }
+        ]"""
+        server.add(
+            responses.POST,
+            "https://example.com/api/panel/syncSendCommand",
+            body=html,
+            status=200,
+        )
+        client = ElmoClient(base_url="https://example.com", domain="domain")
+        client._session_id = "test"
+        # Test
+        assert client.turn_on([3]) is True
+        assert len(server.calls) == 1
+        body = server.calls[0].request.body.split("&")
+        assert "CommandType=1" in body
+        assert "ElementsClass=12" in body
+        assert "ElementsIndexes=3" in body
+        assert "sessionId=test" in body
+
+    def test_client_multiple_outputs(self, server):
+        """Should call the API and activate given outputs."""
+        html = """[
+            {
+                "Poller": {"Poller": 1, "Panel": 1},
+                "CommandId": 147,
+                "Successful": true,
+                "ErrorMessages": []
+            }
+        ]"""
+        server.add(
+            responses.POST,
+            "https://example.com/api/panel/syncSendCommand",
+            body=html,
+            status=200,
+        )
+        client = ElmoClient(base_url="https://example.com", domain="domain")
+        client._session_id = "test"
+        # Test
+        assert client.turn_on([3, 4]) is True
+        assert len(server.calls) == 1
+        body = server.calls[0].request.body.split("&")
+        assert "CommandType=1" in body
+        assert "ElementsClass=12" in body
+        assert "ElementsIndexes=3" in body
+        assert "ElementsIndexes=4" in body
+        assert "sessionId=test" in body
+
+    def test_client_fails_missing_session(self, server):
+        """Should fail if a wrong access token is used."""
+        server.add(
+            responses.POST,
+            "https://example.com/api/panel/syncSendCommand",
+            status=401,
+        )
+        client = ElmoClient(base_url="https://example.com", domain="domain")
+        client._session_id = "test"
+        client._lock.acquire()
+        # Test
+        with pytest.raises(InvalidToken):
+            client.turn_on([1])
+        assert len(server.calls) == 1
+
+    def test_client_fails_wrong_input(self, server):
+        """Should fail if a not existing output is used."""
+        html = """[
+            {
+                "Poller": {"Poller": 1, "Panel": 1},
+                "CommandId": 147,
+                "Successful": false,
+                "ErrorMessages": ["Command failed."]
+            }
+        ]"""
+        server.add(
+            responses.POST,
+            "https://example.com/api/panel/syncSendCommand",
+            body=html,
+            status=200,
+        )
+        client = ElmoClient(base_url="https://example.com", domain="domain")
+        client._session_id = "test"
+        # Test
+        with pytest.raises(InvalidInput):
+            assert client.turn_on([9000])
+
+    def test_client_fails_unknown_error(self, server):
+        """Should fail if an unknown error happens."""
+        server.add(
+            responses.POST,
+            "https://example.com/api/panel/syncSendCommand",
+            body="Server Error",
+            status=500,
+        )
+        client = ElmoClient(base_url="https://example.com", domain="domain")
+        client._session_id = "test"
+        # Test
+        with pytest.raises(HTTPError):
+            client.turn_on([1])
+        assert len(server.calls) == 1
+
+
+class TestTurnOff:
+    def test_client_single_output(self, server):
+        """Should call the API and deactivate given output."""
+        html = """[
+            {
+                "Poller": {"Poller": 1, "Panel": 1},
+                "CommandId": 147,
+                "Successful": true,
+                "ErrorMessages": []
+            }
+        ]"""
+        server.add(
+            responses.POST,
+            "https://example.com/api/panel/syncSendCommand",
+            body=html,
+            status=200,
+        )
+        client = ElmoClient(base_url="https://example.com", domain="domain")
+        client._session_id = "test"
+        # Test
+        assert client.turn_off([3]) is True
+        assert len(server.calls) == 1
+        body = server.calls[0].request.body.split("&")
+        assert "CommandType=2" in body
+        assert "ElementsClass=12" in body
+        assert "ElementsIndexes=3" in body
+        assert "sessionId=test" in body
+
+    def test_client_multiple_outputs(self, server):
+        """Should call the API and deactivate given outputs."""
+        html = """[
+            {
+                "Poller": {"Poller": 1, "Panel": 1},
+                "CommandId": 147,
+                "Successful": true,
+                "ErrorMessages": []
+            }
+        ]"""
+        server.add(
+            responses.POST,
+            "https://example.com/api/panel/syncSendCommand",
+            body=html,
+            status=200,
+        )
+        client = ElmoClient(base_url="https://example.com", domain="domain")
+        client._session_id = "test"
+        # Test
+        assert client.turn_off([3, 4]) is True
+        assert len(server.calls) == 1
+        body = server.calls[0].request.body.split("&")
+        assert "CommandType=2" in body
+        assert "ElementsClass=12" in body
+        assert "ElementsIndexes=3" in body
+        assert "ElementsIndexes=4" in body
+        assert "sessionId=test" in body
+
+    def test_client_fails_missing_session(self, server):
+        """Should fail if a wrong access token is used."""
+        server.add(
+            responses.POST,
+            "https://example.com/api/panel/syncSendCommand",
+            status=401,
+        )
+        client = ElmoClient(base_url="https://example.com", domain="domain")
+        client._session_id = "test"
+        client._lock.acquire()
+        # Test
+        with pytest.raises(InvalidToken):
+            client.turn_off([1])
+        assert len(server.calls) == 1
+
+    def test_client_fails_wrong_input(self, server):
+        """Should fail if a not existing output is used."""
+        html = """[
+            {
+                "Poller": {"Poller": 1, "Panel": 1},
+                "CommandId": 147,
+                "Successful": false,
+                "ErrorMessages": ["Command failed."]
+            }
+        ]"""
+        server.add(
+            responses.POST,
+            "https://example.com/api/panel/syncSendCommand",
+            body=html,
+            status=200,
+        )
+        client = ElmoClient(base_url="https://example.com", domain="domain")
+        client._session_id = "test"
+        # Test
+        with pytest.raises(InvalidInput):
+            assert client.turn_off([9000])
+
+    def test_client_fails_unknown_error(self, server):
+        """Should fail if an unknown error happens."""
+        server.add(
+            responses.POST,
+            "https://example.com/api/panel/syncSendCommand",
+            body="Server Error",
+            status=500,
+        )
+        client = ElmoClient(base_url="https://example.com", domain="domain")
+        client._session_id = "test"
+        # Test
+        with pytest.raises(HTTPError):
+            client.turn_off([1])
+        assert len(server.calls) == 1
+
+
 def test_client_get_descriptions(server):
     """Should retrieve inputs/sectors descriptions."""
     html = """
@@ -1275,7 +1669,7 @@ def test_client_get_sectors_status(server, mocker):
            "Active": false,
            "ActivePartial": false,
            "Max": false,
-           "Activable": true,
+           "Activable": false,
            "ActivablePartial": false,
            "InUse": true,
            "Id": 3,
@@ -1319,7 +1713,7 @@ def test_client_get_sectors_status(server, mocker):
                 "id": 1,
                 "index": 0,
                 "status": True,
-                "excluded": False,
+                "activable": True,
                 "name": "Living Room",
             },
             1: {
@@ -1327,7 +1721,7 @@ def test_client_get_sectors_status(server, mocker):
                 "id": 2,
                 "index": 1,
                 "status": True,
-                "excluded": False,
+                "activable": True,
                 "name": "Bedroom",
             },
             2: {
@@ -1335,7 +1729,7 @@ def test_client_get_sectors_status(server, mocker):
                 "id": 3,
                 "index": 2,
                 "status": False,
-                "excluded": False,
+                "activable": False,
                 "name": "Kitchen",
             },
         },
@@ -1438,6 +1832,102 @@ def test_client_get_inputs_status(server, mocker):
     }
 
 
+def test_client_get_outputs_status(server, mocker):
+    """Should query a Elmo system to retrieve outputs status."""
+    html = """[
+       {
+        "Active": true,
+        "InUse": true,
+        "DoNotRequireAuthentication": true,
+        "ControlDeniedToUsers": false,
+        "Id": 400258,
+        "Index": 0,
+        "Element": 1,
+        "CommandId": 0,
+        "InProgress": false
+    },
+    {
+        "Active": false,
+        "InUse": true,
+        "DoNotRequireAuthentication": false,
+        "ControlDeniedToUsers": false,
+        "Id": 400259,
+        "Index": 1,
+        "Element": 2,
+        "CommandId": 0,
+        "InProgress": false
+    },
+    {
+        "Active": false,
+        "InUse": true,
+        "DoNotRequireAuthentication": false,
+        "ControlDeniedToUsers": true,
+        "Id": 400260,
+        "Index": 2,
+        "Element": 3,
+        "CommandId": 0,
+        "InProgress": false
+    },
+    {
+        "Active": false,
+        "InUse": false,
+        "DoNotRequireAuthentication": false,
+        "ControlDeniedToUsers": false,
+        "Id": 400261,
+        "Index": 3,
+        "Element": 4,
+        "CommandId": 0,
+        "InProgress": false
+    }
+    ]"""
+    # query() depends on _get_descriptions()
+    server.add(responses.POST, "https://example.com/api/outputs", body=html, status=200)
+    client = ElmoClient(base_url="https://example.com", domain="domain")
+    client._session_id = "test"
+    mocker.patch.object(client, "_get_descriptions")
+    client._get_descriptions.return_value = {
+        12: {0: "Output 1", 1: "Output 2", 2: "Output 3", 3: "Output 4"},
+    }
+    # Test
+    outputs = client.query(query.OUTPUTS)
+    # Expected output
+    assert client._get_descriptions.called is True
+    assert len(server.calls) == 1
+
+    assert outputs == {
+        "last_id": 400261,
+        "outputs": {
+            0: {
+                "element": 1,
+                "id": 400258,
+                "index": 0,
+                "status": True,
+                "control_denied_to_users": False,
+                "do_not_require_authentication": True,
+                "name": "Output 1",
+            },
+            1: {
+                "element": 2,
+                "id": 400259,
+                "index": 1,
+                "status": False,
+                "control_denied_to_users": False,
+                "do_not_require_authentication": False,
+                "name": "Output 2",
+            },
+            2: {
+                "element": 3,
+                "id": 400260,
+                "status": False,
+                "index": 2,
+                "control_denied_to_users": True,
+                "do_not_require_authentication": False,
+                "name": "Output 3",
+            },
+        },
+    }
+
+
 def test_client_get_sectors_missing_area(server, mocker):
     """Should set an Unknown `sector` name if the description is missing.
     Regression test for: https://github.com/palazzem/econnect-python/issues/91"""
@@ -1486,7 +1976,7 @@ def test_client_get_sectors_missing_area(server, mocker):
                 "id": 1,
                 "index": 0,
                 "status": True,
-                "excluded": False,
+                "activable": True,
                 "name": "Living Room",
             },
             1: {
@@ -1494,7 +1984,7 @@ def test_client_get_sectors_missing_area(server, mocker):
                 "id": 2,
                 "index": 1,
                 "status": True,
-                "excluded": False,
+                "activable": True,
                 "name": "Unknown",
             },
         },
@@ -1680,31 +2170,34 @@ def test_client_get_alerts_status(server):
     assert body == "sessionId=test"
     # Expected output
     assert alerts == {
-        0: {"name": "alarm_led", "status": 0},
-        1: {"name": "anomalies_led", "status": 1},
-        2: {"name": "device_failure", "status": 0},
-        3: {"name": "device_low_battery", "status": 0},
-        4: {"name": "device_no_power", "status": 0},
-        5: {"name": "device_no_supervision", "status": 0},
-        6: {"name": "device_system_block", "status": 0},
-        7: {"name": "device_tamper", "status": 0},
-        8: {"name": "gsm_anomaly", "status": 0},
-        9: {"name": "gsm_low_balance", "status": 0},
-        10: {"name": "has_anomaly", "status": False},
-        11: {"name": "input_alarm", "status": 0},
-        12: {"name": "input_bypass", "status": 0},
-        13: {"name": "input_failure", "status": 0},
-        14: {"name": "input_low_battery", "status": 0},
-        15: {"name": "input_no_supervision", "status": 0},
-        16: {"name": "inputs_led", "status": 2},
-        17: {"name": "module_registration", "status": 0},
-        18: {"name": "panel_low_battery", "status": 0},
-        19: {"name": "panel_no_power", "status": 0},
-        20: {"name": "panel_tamper", "status": 0},
-        21: {"name": "pstn_anomaly", "status": 0},
-        22: {"name": "rf_interference", "status": 0},
-        23: {"name": "system_test", "status": 0},
-        24: {"name": "tamper_led", "status": 0},
+        "last_id": 1,
+        "alerts": {
+            0: {"name": "alarm_led", "status": 0},
+            1: {"name": "anomalies_led", "status": 1},
+            2: {"name": "device_failure", "status": 0},
+            3: {"name": "device_low_battery", "status": 0},
+            4: {"name": "device_no_power", "status": 0},
+            5: {"name": "device_no_supervision", "status": 0},
+            6: {"name": "device_system_block", "status": 0},
+            7: {"name": "device_tamper", "status": 0},
+            8: {"name": "gsm_anomaly", "status": 0},
+            9: {"name": "gsm_low_balance", "status": 0},
+            10: {"name": "has_anomaly", "status": False},
+            11: {"name": "input_alarm", "status": 0},
+            12: {"name": "input_bypass", "status": 0},
+            13: {"name": "input_failure", "status": 0},
+            14: {"name": "input_low_battery", "status": 0},
+            15: {"name": "input_no_supervision", "status": 0},
+            16: {"name": "inputs_led", "status": 2},
+            17: {"name": "module_registration", "status": 0},
+            18: {"name": "panel_low_battery", "status": 0},
+            19: {"name": "panel_no_power", "status": 0},
+            20: {"name": "panel_tamper", "status": 0},
+            21: {"name": "pstn_anomaly", "status": 0},
+            22: {"name": "rf_interference", "status": 0},
+            23: {"name": "system_test", "status": 0},
+            24: {"name": "tamper_led", "status": 0},
+        },
     }
 
 
